@@ -1,8 +1,4 @@
-__version__ = '0.0.20'  # print(ultralytics.__version__)
-
-from .yolov5_wrapper import clone_yolo
-
-clone_yolo()
+__version__ = '0.0.21'  # print(ultralytics.__version__)
 
 
 def login():
